<?php
/**
 * Study Abroad options
 *
 * @package Theme Palace
 * @subpackage Corporate Education Pro
 * @since Corporate Education Pro 1.0
 */

// Add panel for section options
$wp_customize->add_panel( 'corporate_education_pro_study_abroad_panel' , array(
    'title'      => esc_html__( 'Study Abroad Template','corporate-education-pro' ),
    'description'=> esc_html__( 'Study Abroad Template Options', 'corporate-education-pro' ),
    'priority'   => 150,
) );

/*
 * Destination Section
 */

$wp_customize->add_section( 'corporate_education_pro_destination', array(
	'title'             => esc_html__( 'Destination Section','corporate-education-pro' ),
	'description'       => esc_html__( 'Destination section options.', 'corporate-education-pro' ),
	'panel'             => 'corporate_education_pro_study_abroad_panel',
) );

// Destination enable setting and control.
$wp_customize->add_setting( 'corporate_education_pro_theme_options[destination_enable]', array(
	'sanitize_callback'	=> 'corporate_education_pro_sanitize_checkbox',
	'default'          	=> $options['destination_enable'],
) );

$wp_customize->add_control( 'corporate_education_pro_theme_options[destination_enable]', array(
	'label'            	=> esc_html__( 'Enable Destination', 'corporate-education-pro' ),
	'section'          	=> 'corporate_education_pro_destination',
	'type'             	=> 'checkbox',
) );

// Destination Section content type setting and control.
$wp_customize->add_setting( 'corporate_education_pro_theme_options[destination_content_type]', array(
	'sanitize_callback'	=> 'corporate_education_pro_sanitize_select',
) );

$wp_customize->add_control( 'corporate_education_pro_theme_options[destination_content_type]', array(
	'label'            	=> esc_html__( 'Content Type', 'corporate-education-pro' ),
	'section'          	=> 'corporate_education_pro_destination',
	'type'             	=> 'select',
	'active_callback'	=> 'corporate_education_pro_is_abroad_study_destination_enable',
	'choices'			=> corporate_education_pro_study_abroad_destination(),
) );

// Add destination number setting and control.
$wp_customize->add_setting( 'corporate_education_pro_theme_options[study_abroad_destination_count]', array(
	'default'           => $options['study_abroad_destination_count'],
	'sanitize_callback' => 'corporate_education_pro_sanitize_number_range',
	'validate_callback' => 'corporate_education_pro_validate_destination_count',
) );

$wp_customize->add_control( 'corporate_education_pro_theme_options[study_abroad_destination_count]', array(
	'label'           	=> esc_html__( 'Number of Destinations', 'corporate-education-pro' ),
	'description'       => esc_html__( 'Note: Min 3 & Max 6. Please input the valid number and save.', 'corporate-education-pro' ),
	'section'         	=> 'corporate_education_pro_destination',
	'type'            	=> 'number',
	'active_callback' 	=> 'corporate_education_pro_study_abroad_destination_count',
	'input_attrs'     	=> array(
		'max' 	=> 6,
		'min' 	=> 3,
		'style' => 'width:100px'
	)
) );

// destination Section content type post setting and control.
$wp_customize->add_setting( 'corporate_education_pro_theme_options[study_abroad_destination_post]', array(
	'validate_callback' => 'corporate_education_pro_validate_post_id',
	'sanitize_callback' => 'corporate_education_pro_sanitize_post_ids',
) );

$wp_customize->add_control( 'corporate_education_pro_theme_options[study_abroad_destination_post]', array(
	'active_callback'	=> 'corporate_education_pro_study_abroad_destination_post',
	'label'             => esc_html__( 'Input Post Ids', 'corporate-education-pro' ),
	'description'       => esc_html__( 'Max no. of posts allowed is 6. ie: 11, 24, 34', 'corporate-education-pro' ),
	'section'           => 'corporate_education_pro_destination',
	'type'				=> 'text',
) );

// destination Section category setting and control
$wp_customize->add_setting( 'corporate_education_pro_theme_options[study_abroad_destination_category]', array(
	'sanitize_callback' => 'corporate_education_pro_sanitize_single_category'
) );

$wp_customize->add_control( new Corporate_Education_Pro_Dropdown_Single_Category_Control( $wp_customize, 'corporate_education_pro_theme_options[study_abroad_destination_category]', array(
	'label'           => esc_html__( 'Select Category', 'corporate-education-pro' ),
	'description'     => esc_html__( 'Latest posts from selected category will be shown.', 'corporate-education-pro' ),
	'section'         => 'corporate_education_pro_destination',
	'type'			  => 'dropdown-category',
	'active_callback' => 'corporate_education_pro_study_abroad_destination_category',
) ) );

// destination Section content type excursion setting and control.
$wp_customize->add_setting( 'corporate_education_pro_theme_options[study_abroad_destination_excursion]', array(
	'validate_callback' => 'corporate_education_pro_validate_post_id',
	'sanitize_callback' => 'corporate_education_pro_sanitize_post_ids',
) );

$wp_customize->add_control( 'corporate_education_pro_theme_options[study_abroad_destination_excursion]', array(
	'active_callback'	=> 'corporate_education_pro_study_abroad_destination_excursion',
	'label'             => esc_html__( 'Input Excursion Ids', 'corporate-education-pro' ),
	'description'       => esc_html__( 'Max no. of posts allowed is 6. ie: 11, 24, 34', 'corporate-education-pro' ),
	'section'           => 'corporate_education_pro_destination',
	'type'				=> 'text',
) );

// destination Section excursion category setting and control
$wp_customize->add_setting( 'corporate_education_pro_theme_options[study_abroad_destination_excursion_category]', array(
	'sanitize_callback' => 'absint'
) );

$wp_customize->add_control( new Corporate_Education_Pro_Dropdown_Single_Category_Control( $wp_customize, 'corporate_education_pro_theme_options[study_abroad_destination_excursion_category]', array(
	'label'           => esc_html__( 'Select Excursion Category', 'corporate-education-pro' ),
	'description'     => esc_html__( 'Latest excursions from selected category will be shown.', 'corporate-education-pro' ),
	'section'         => 'corporate_education_pro_destination',
	'taxonomy'		  => 'tp-excursion-category',
	'type'			  => 'dropdown-category',
	'active_callback' => 'corporate_education_pro_study_abroad_destination_excursion_category',
) ) );


/*
 * Abroad Study Guide Section
 */

$wp_customize->add_section( 'corporate_education_pro_guide', array(
	'title'             => esc_html__( 'Study Guide Section','corporate-education-pro' ),
	'description'       => esc_html__( 'Study Guide section options.', 'corporate-education-pro' ),
	'panel'             => 'corporate_education_pro_study_abroad_panel',
) );

// Guide enable setting and control.
$wp_customize->add_setting( 'corporate_education_pro_theme_options[study_guide_enable]', array(
	'sanitize_callback'	=> 'corporate_education_pro_sanitize_checkbox',
	'default'          	=> $options['study_guide_enable'],
) );

$wp_customize->add_control( 'corporate_education_pro_theme_options[study_guide_enable]', array(
	'label'            	=> esc_html__( 'Enable Study Guide', 'corporate-education-pro' ),
	'section'          	=> 'corporate_education_pro_guide',
	'type'             	=> 'checkbox',
) );

// Guide title setting and control.
$wp_customize->add_setting( 'corporate_education_pro_theme_options[study_guide_title]', array(
	'sanitize_callback'	=> 'sanitize_text_field',
	'default'          	=> $options['study_guide_title'],
) );

$wp_customize->add_control( 'corporate_education_pro_theme_options[study_guide_title]', array(
	'label'            	=> esc_html__( 'Title', 'corporate-education-pro' ),
	'section'          	=> 'corporate_education_pro_guide',
	'type'             	=> 'text',
) );

// Guide sub title setting and control.
$wp_customize->add_setting( 'corporate_education_pro_theme_options[study_guide_sub_title]', array(
	'sanitize_callback'	=> 'sanitize_text_field',
	'default'          	=> $options['study_guide_sub_title'],
) );

$wp_customize->add_control( 'corporate_education_pro_theme_options[study_guide_sub_title]', array(
	'label'            	=> esc_html__( 'Sub Title', 'corporate-education-pro' ),
	'section'          	=> 'corporate_education_pro_guide',
	'type'             	=> 'text',
) );

// Guide Section content type setting and control.
$wp_customize->add_setting( 'corporate_education_pro_theme_options[study_guide_content_type]', array(
	'sanitize_callback'	=> 'corporate_education_pro_sanitize_select',
) );

$wp_customize->add_control( 'corporate_education_pro_theme_options[study_guide_content_type]', array(
	'label'            	=> esc_html__( 'Content Type', 'corporate-education-pro' ),
	'section'          	=> 'corporate_education_pro_guide',
	'type'             	=> 'select',
	'active_callback'	=> 'corporate_education_pro_is_abroad_study_destination_enable',
	'choices'			=> corporate_education_pro_study_guide(),
) );

// study guide Section content type post setting and control.
$wp_customize->add_setting( 'corporate_education_pro_theme_options[study_guide_content_post]', array(
	'validate_callback' => 'corporate_education_pro_validate_post_id',
	'sanitize_callback' => 'corporate_education_pro_sanitize_post_ids',
) );

$wp_customize->add_control( 'corporate_education_pro_theme_options[study_guide_content_post]', array(
	'active_callback'	=> 'corporate_education_pro_study_guide_content_post',
	'label'             => esc_html__( 'Input Post Ids', 'corporate-education-pro' ),
	'description'       => esc_html__( 'Max no. of posts allowed is 9. ie: 11, 24, 34', 'corporate-education-pro' ),
	'section'           => 'corporate_education_pro_guide',
	'type'				=> 'text',
) );

// Add destination number setting and control.
$wp_customize->add_setting( 'corporate_education_pro_theme_options[study_guide_count]', array(
	'default'           => $options['study_guide_count'],
	'sanitize_callback' => 'corporate_education_pro_sanitize_number_range',
	'validate_callback' => 'corporate_education_pro_validate_study_guide_count',
) );

$wp_customize->add_control( 'corporate_education_pro_theme_options[study_guide_count]', array(
	'label'           	=> esc_html__( 'Number of Guides', 'corporate-education-pro' ),
	'description'       => esc_html__( 'Note: Min 3 & Max 9. Please input the valid number and save.', 'corporate-education-pro' ),
	'section'         	=> 'corporate_education_pro_guide',
	'type'            	=> 'number',
	'active_callback' 	=> 'corporate_education_pro_study_guide_content_category',
	'input_attrs'     	=> array(
		'max' 	=> 9,
		'min' 	=> 3,
		'style' => 'width:100px'
	)
) );

// study guide Section category setting and control
$wp_customize->add_setting( 'corporate_education_pro_theme_options[study_guide_content_category]', array(
	'sanitize_callback' => 'corporate_education_pro_sanitize_single_category'
) );

$wp_customize->add_control( new Corporate_Education_Pro_Dropdown_Single_Category_Control( $wp_customize, 'corporate_education_pro_theme_options[study_guide_content_category]', array(
	'label'           => esc_html__( 'Select Category', 'corporate-education-pro' ),
	'description'     => esc_html__( 'Latest posts from selected category will be shown.', 'corporate-education-pro' ),
	'section'         => 'corporate_education_pro_guide',
	'type'			  => 'dropdown-category',
	'active_callback' => 'corporate_education_pro_study_guide_content_category',
) ) );