<?php
/**
 * Customizer default options
 *
 * @package Theme Palace
 * @subpackage Corporate Education Pro
 * @since Corporate Education Pro 1.0
 * @return array An array of default values
 */

function corporate_education_pro_get_default_theme_options() {
	$theme_data = wp_get_theme();
	$corporate_education_pro_default_options = array(

		// Theme Options
		'theme_typography' 				=> 'default',
		'body_theme_typography' 		=> 'default',
		'theme_menu' 					=> 'modern-menu',
		'loader_enable'         		=> false,
		'loader_icon'         			=> 'fa-spinner',
		'site_layout'         			=> 'wide',
		'theme_layout'         			=> 'curve',
		'theme_color'         			=> 'blue',
		'sidebar_position'         		=> 'right-sidebar',
		'long_excerpt_length'           => 25,
		'short_excerpt_length'          => 10,
		'read_more_text'		        => esc_html__( 'Read More', 'corporate-education-pro' ),
		'breadcrumb_enable'         	=> true,
		'pagination_enable'         	=> true,
		'pagination_type'         		=> 'default',
		'copyright_text'                => sprintf( _x( 'Copyright &copy; %1$s %2$s. All Rights Reserved', '1: Year, 2: Site Title with home URL', 'corporate-education-pro' ), '[the-year]', '[site-link]' ) . ' &#124; ' . esc_html( $theme_data->get( 'Name') ) . '&nbsp;' . __( 'by', 'corporate-education-pro' ). '&nbsp;<a target="_blank" href="'. esc_url( $theme_data->get( 'AuthorURI' ) ) .'">'. esc_html( ucwords( $theme_data->get( 'Author' ) ) ) .'</a>',
		'scroll_top_visible'        	=> true,
		'reset_options'      			=> false,
		'enable_frontpage_content' 		=> true,
		'author_box_enable' 			=> true,
		'post_navigation_enable' 		=> true,
		'menu_sticky' 					=> false,
		'menu_transparent' 				=> false,
		'menu_text' 					=> false,

		// Headline Section
		'headline_enable'				=> true,
		'headline_label'				=> esc_html__( 'News', 'corporate-education-pro' ),
		'headline_content_type'			=> 'demo',
		'headline_content_count'		=> 6,

		// Slider Section
		'slider_enable'					=> true,
		'slider_overlay_enable'			=> false,
		'slider_effect'					=> 'fade',
		'slider_transition_duration'	=> '1000',
		'enable_slider_controls'		=> true,
		'enable_slider_pager'			=> true,
		'enable_slider_dragable'		=> true,
		'slider_autoplay'				=> true,
		'slider_pause_on_hover'			=> true,
		'slider_content_type'			=> 'demo',
		'no_of_slider'					=> 3,
		'slider_btn_label'				=> esc_html__( 'Start Learning', 'corporate-education-pro' ),

		// About Section
		'about_enable'					=> true,
		'about_content_type'			=> 'demo',
		'about_content_column'			=> 2,
		'about_image'					=> get_template_directory_uri() . '/assets/uploads/letter-backgound.jpg',
		'about_title'					=> esc_html__( 'About Us', 'corporate-education-pro' ),
		'about_sub_title'				=> esc_html__( 'Know Who We Are', 'corporate-education-pro' ),
		'about_alphabet'				=> esc_html__( 'A', 'corporate-education-pro' ),
		'about_excerpt'					=> esc_html__( 'Lorem ipsum dolor sit amet, consectetur adipiscing elit. Etiam eget augue quis elit tempor laoreet. Vestibulum purus quam, vestibulum sed malesuada id, hendrerit nec dolor. Nulla risus erat, rutrum id felis non, efficitur varius mi. Interdum et malesuada fames ac ante ipsum primis in faucibus. Pellentesque sagittis gravida dolor, sed auctor risus faucibus eu.Integer finibus purus eu velit vestibulum, at scelerisque arcu tempor. Nam at justo sed tortor condimentum mollis. Donec nec urna dui. Sed ut iaculis lacus. Morbi vulputate sapien risus, non finibus diam suscipit porttitor. Nunc eu rhoncus mi, quis aliquam nisi.', 'corporate-education-pro' ),

		// Service Section
		'service_enable'				=> true,
		'service_intro_content_type'	=> 'demo',
		'service_intro_image'			=> get_template_directory_uri() . '/assets/uploads/featured-service.jpg',
		'service_intro_title'			=> esc_html__( 'Best For You', 'corporate-education-pro' ),
		'service_intro_sub_title'		=> esc_html__( 'Our Quality Service', 'corporate-education-pro' ),
		'service_intro_description'		=> esc_html__( 'OLorem ipsum dolor sit amet, consectetur adipiscing elit. Etiam eget augue quis elit tempor laoreet. Vestibulum purus quam, vestibulum sed malesuada id, hendrerit nec dolor. Nulla risus erat, rutrum id felis non, efficitur varius mi. Interdum et malesuada fames ac ante ipsum primis in tempor laoree faucibus.', 'corporate-education-pro' ),
		'service_intro_btn_label'		=> esc_html__( 'Learn More', 'corporate-education-pro' ),
		'service_content_type'			=> 'demo',

		// Courses Section
		'courses_enable'				=> true,
		'courses_content_type'			=> 'demo',
		'courses_title'					=> esc_html__( 'Our Courses', 'corporate-education-pro' ),
		'courses_sub_title'				=> esc_html__( 'Learn With Us', 'corporate-education-pro' ),
		'no_of_courses'					=> 3,

		// call to action section
		'call_to_action_enable'			=> true,
		'call_to_action_type'			=> 'demo',
		'call_to_action_title'			=> esc_html__( 'Your success..!! Is our goal..!!', 'corporate-education-pro' ),
		'call_to_action_sub_title'		=> esc_html__( 'Build your career with us', 'corporate-education-pro' ),
		'call_to_action_btn_label_1'	=> esc_html__( 'Start Learning', 'corporate-education-pro' ),
		'call_to_action_btn_label_2'	=> esc_html__( 'Contact Us Now', 'corporate-education-pro' ),
		'call_to_action_btn_url_1'		=> '#',
		'call_to_action_btn_url_2'		=> '#',
		'call_to_action_image'			=> get_template_directory_uri() . '/assets/uploads/promotion.jpg',

		// latest news
		'latest_news_enable'			=> true,
		'latest_news_count'				=> 4,
		'latest_news_title_1'			=> esc_html__( 'Events', 'corporate-education-pro' ),
		'latest_news_sub_title_1'		=> esc_html__( 'Happening Around Us', 'corporate-education-pro' ),
		'latest_news_content_type_1'	=> 'demo',
		'latest_news_title_2'			=> esc_html__( 'News', 'corporate-education-pro' ),
		'latest_news_sub_title_2'		=> esc_html__( 'Our Latest Activities', 'corporate-education-pro' ),
		'latest_news_content_type_2'	=> 'demo',

		// team
		'team_enable'					=> true,
		'team_intro_content_type'		=> 'demo',
		'team_intro_title'				=> esc_html__( 'Professional Teachers', 'corporate-education-pro' ),
		'team_intro_sub_title'			=> esc_html__( 'Our Qualified Manpower', 'corporate-education-pro' ),
		'team_intro_description'		=> esc_html__( 'OLorem ipsum dolor sit amet, consectetur adipiscing elit. Etiam eget augue quis elit tempor laoreet. Vestibulum purus quam, vestibulum sed malesuada id, hendrerit nec dolor. Nulla risus erat, rutrum id felis non, efficitur varius mi. Interdum et malesuada fames ac ante ipsum primis in tempor laoree faucibus.', 'corporate-education-pro' ),
		'team_intro_btn_label'			=> esc_html__( 'Learn More', 'corporate-education-pro' ),
		'team_content_type'				=> 'demo',

		// counter
		'counter_enable'				=> true,
		'counter_icon_1'				=> 'fa-bookmark',	
		'counter_icon_2'				=> 'fa-users',	
		'counter_icon_3'				=> 'fa-graduation-cap',	
		'counter_icon_4'				=> 'fa-calendar',
		'counter_count_1'				=> esc_html__( '124', 'corporate-education-pro' ),	
		'counter_count_2'				=> esc_html__( '85', 'corporate-education-pro' ),		
		'counter_count_3'				=> esc_html__( '150', 'corporate-education-pro' ),	
		'counter_count_4'				=> esc_html__( '268', 'corporate-education-pro' ),	
		'counter_title_1'				=> esc_html__( 'Our Courses', 'corporate-education-pro' ),	
		'counter_title_2'				=> esc_html__( 'No. of Staffs', 'corporate-education-pro' ),		
		'counter_title_3'				=> esc_html__( 'Graduates', 'corporate-education-pro' ),	
		'counter_title_4'				=> esc_html__( 'Successful Events', 'corporate-education-pro' ),

		// testimonial
		'testimonial_enable'			=> true,	
		'testimonial_title'				=> esc_html__( 'Testimonials', 'corporate-education-pro' ),	
		'testimonial_sub_title'			=> esc_html__( 'What others think of us', 'corporate-education-pro' ),	
		'testimonial_content_type'		=> 'demo',	
		'no_of_testimonial'				=> 4,	

		// gallery
		'gallery_enable'				=> true,
		'gallery_title'					=> esc_html__( 'Showcase Of Memory', 'corporate-education-pro' ),
		'gallery_sub_title'				=> esc_html__( 'Our Gallery', 'corporate-education-pro' ),
		'gallery_content_type'			=> 'demo',
		'gallery_btn_label'				=> esc_html__( 'View All Photos', 'corporate-education-pro' ),
		'gallery_btn_link'				=> '#',

		// subscribe
		'subscribe_enable'				=> false,
		'subscribe_title'				=> esc_html__( 'Get Notified', 'corporate-education-pro' ),
		'subscribe_sub_title'			=> esc_html__( 'Subscribe to our newsletter', 'corporate-education-pro' ),
		'subscribe_btn_label'			=> esc_html__( 'Subscribe Now', 'corporate-education-pro' ),
		'subscribe_success_message'		=> esc_html__( 'Success! An email was just sent to confirm your subscription. Please find the email now and click ( Confirm Follow ) to start subscribing.', 'corporate-education-pro' ),
		'subscribe_image'				=> get_template_directory_uri() . '/assets/uploads/background-01.jpg',

		// social
		'social_enable'					=> true,
		'social_entire_site_enable'		=> false,
		'social_title_link_1'			=> esc_url( 'http://facebook.com' ),
		'social_title_link_2'			=> esc_url( 'http://twitter.com' ),
		'social_title_link_3'			=> esc_url( 'http://instagram.com' ),
		'social_title_link_4'			=> esc_url( 'http://plus.google.com' ),
		'social_title_link_5'			=> esc_url( 'http://pinterest.com' ),

		// Study Abroad Template
		'destination_enable'			=> true,
		'destination_content_type'		=> 'post',
		'study_abroad_destination_count' => 3,
		'study_guide_enable'			=> true,
		'study_guide_content_type'		=> 'post',
		'study_guide_count'				=> 6,
		'study_guide_title'				=> esc_html__( 'Abroad Study Guide', 'corporate-education-pro' ),
		'study_guide_sub_title'			=> esc_html__( 'Tools & Resources', 'corporate-education-pro' ),

		// services template
		'goal_section_enable'			=> true,
		'goal_intro_content_type'		=> 'custom',
		'goal_intro_content_title'		=> esc_html__( 'Our Goal', 'corporate-education-pro' ),
		'goal_intro_content_sub_title'	=> esc_html__( 'We prepare you for future', 'corporate-education-pro' ),
		'goal_intro_content_description' => esc_html__( 'Lorem ipsum dolor sit amet, consectetur adipiscing elit. Aenean aliquet erat mauris, ut ultrices ex accumsan at. Nunc vitae tellus tincidunt, viverra elit vel, rutrum leo. Etiam in aliquet ligula. Cras congue, purus sit amet tincidunt imperdiet, enim lacus pulvinar est, in maximus mauris velit vel felis. Sed pharetra lectus sapien.', 'corporate-education-pro' ),
		'goal_content_type'				=> 'post',
		'main_service_content_type'		=> 'post',
		'main_service_enable'			=> true,
		'main_service_title'			=> esc_html__( 'Main Services', 'corporate-education-pro' ),
		'main_service_sub_title'		=> esc_html__( 'Our Quality Services', 'corporate-education-pro' ),
		'main_service_image'			=> get_template_directory_uri() . '/assets/uploads/main-service.jpg',
		'quality_service_enable'		=> true,
		'quality_service_content_type'	=> 'post',
		'quality_service_count'			=> 6,
		'quality_service_title'			=> esc_html__( 'Why Choose Us', 'corporate-education-pro' ),
		'quality_service_sub_title'		=> esc_html__( 'Our Quality Services', 'corporate-education-pro' ),

		// about us template
		'about_image_enable'			=> true,
		'message_enable'				=> true,
		'message_content_type'			=> 'custom',
		'message_title'					=> esc_html__( 'Ricky Ortega', 'corporate-education-pro' ),
		'message_sub_title'				=> esc_html__( 'The Principle, Learnable Education College', 'corporate-education-pro' ),
		'message_description'			=> esc_html__( 'Lorem ipsum dolor sit amet, consectetur adipiscing elit. Nullam efficitur tortor vel gravida egestas. Sed nec ligula pharetra, porta sem a, dapibus ipsum. Pellentesque facilisis facilisis interdum. Quisque faucibus enim arcu. Duis vitae turpis sed tortor mattis laoreet. Suspendisse non mi a nunc pulvinar bibendum., Learnable Education College', 'corporate-education-pro' ),
		'message_link'					=> '#',
		'features_enable'				=> true,
		'features_title'				=> esc_html__( 'Key Features', 'corporate-education-pro' ),
		'features_description'			=> esc_html__( 'Morbi vulputate sapien risus, non finibus diam sus cipit porttitor.', 'corporate-education-pro' ),
		'features_content_type'			=> 'post',
		'about_team_enable'				=> true,
		'about_team_title'				=> esc_html__( 'Professional Teachers', 'corporate-education-pro' ),
		'about_team_sub_title'			=> esc_html__( 'Our Qualified Manpower', 'corporate-education-pro' ),
		'about_team_description'		=> esc_html__( 'Suspendisse nec orci ornare, viverra sem eget, rutrum lorem. Ut quis euismod leo. Vestibulum eu dolor vulputate, posuere elit ac, pellentesque orci. Vestibulum feugiat est sed faucibus lobortis. Nam tincidunt leo non dolor tristique convallis. Interdum et malesuada fames ac ante ipsum primis in faucibus.', 'corporate-education-pro' ),
		'about_team_content_type'		=> 'category',

		// contact page
		'contact_map_enable'			=> true,
		'map_content_type'				=> 'shortcode',

	);

	$output = apply_filters( 'corporate_education_pro_default_theme_options', $corporate_education_pro_default_options );
	// Sort array in ascending order, according to the key:
	if ( ! empty( $output ) ) {
		ksort( $output );
	}

	return $output;
}