<?php
/**
 * Gallery Section options
 *
 * @package Theme Palace
 * @subpackage Corporate Education Pro
 * @since Corporate Education Pro 1.0
 */

$wp_customize->add_section( 'corporate_education_pro_gallery', array(
	'title'             => esc_html__( 'Gallery','corporate-education-pro' ),
	'description'       => esc_html__( 'Gallery Section Options.', 'corporate-education-pro' ),
	'panel'             => 'corporate_education_pro_sections_panel',
) );

// gallery Section enable setting and control.
$wp_customize->add_setting( 'corporate_education_pro_theme_options[gallery_enable]', array(
	'sanitize_callback'	=> 'corporate_education_pro_sanitize_checkbox',
	'default'          	=> $options['gallery_enable'],
) );

$wp_customize->add_control( 'corporate_education_pro_theme_options[gallery_enable]', array(
	'label'            	=> esc_html__( 'Enable Gallery Section', 'corporate-education-pro' ),
	'section'          	=> 'corporate_education_pro_gallery',
	'type'             	=> 'checkbox',
) );

// gallery Section title setting and control.
$wp_customize->add_setting( 'corporate_education_pro_theme_options[gallery_title]', array(
	'sanitize_callback'	=> 'sanitize_text_field',
	'default'          	=> $options['gallery_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'corporate_education_pro_theme_options[gallery_title]', array(
	'label'            	=> esc_html__( 'Title', 'corporate-education-pro' ),
	'section'          	=> 'corporate_education_pro_gallery',
	'type'             	=> 'text',
	'active_callback'	=> 'corporate_education_pro_is_gallery_enable',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'corporate_education_pro_theme_options[gallery_title]', array(
		'selector'            => '#photo-gallery .wrapper .entry-header h2.entry-title',
		'settings'            => 'corporate_education_pro_theme_options[gallery_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'corporate_education_pro_gallery_title',
    ) );
}

// gallery Section subtitle setting and control.
$wp_customize->add_setting( 'corporate_education_pro_theme_options[gallery_sub_title]', array(
	'sanitize_callback'	=> 'sanitize_text_field',
	'default'          	=> $options['gallery_sub_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'corporate_education_pro_theme_options[gallery_sub_title]', array(
	'label'            	=> esc_html__( 'Sub Title', 'corporate-education-pro' ),
	'section'          	=> 'corporate_education_pro_gallery',
	'type'             	=> 'text',
	'active_callback'	=> 'corporate_education_pro_is_gallery_enable',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'corporate_education_pro_theme_options[gallery_sub_title]', array(
		'selector'            => '#photo-gallery .wrapper .entry-header p.entry-title-desc',
		'settings'            => 'corporate_education_pro_theme_options[gallery_sub_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'corporate_education_pro_gallery_sub_title',
    ) );
}

// gallery Section content type setting and control.
$wp_customize->add_setting( 'corporate_education_pro_theme_options[gallery_content_type]', array(
	'default'          	=> $options['gallery_content_type'],
	'sanitize_callback'	=> 'corporate_education_pro_sanitize_select',
) );

$wp_customize->add_control( 'corporate_education_pro_theme_options[gallery_content_type]', array(
	'label'            	=> esc_html__( 'Gallery Content Type', 'corporate-education-pro' ),
	'section'          	=> 'corporate_education_pro_gallery',
	'type'             	=> 'select',
	'active_callback'	=> 'corporate_education_pro_is_gallery_enable',
	'choices'			=> corporate_education_pro_gallery_content_type(),
) );

// gallery Section content type post setting and control.
$wp_customize->add_setting( 'corporate_education_pro_theme_options[gallery_content_post]', array(
	'validate_callback' => 'corporate_education_pro_validate_post_id',
	'sanitize_callback' => 'corporate_education_pro_sanitize_post_ids',
) );

$wp_customize->add_control( 'corporate_education_pro_theme_options[gallery_content_post]', array(
	'active_callback'	=> 'corporate_education_pro_gallery_content_post',
	'label'             => esc_html__( 'Input Post Ids', 'corporate-education-pro' ),
	'description'       => esc_html__( 'Simply hover post title on dashboard to see the Post ID. Max no. of posts allowed is 6. Make sure post has featured image. ie: 11, 24, 34', 'corporate-education-pro' ),
	'section'           => 'corporate_education_pro_gallery',
	'type'				=> 'text',
) );

// gallery Section category setting and control
$wp_customize->add_setting( 'corporate_education_pro_theme_options[gallery_content_category]', array(
	'sanitize_callback' => 'corporate_education_pro_sanitize_single_category'
) );

$wp_customize->add_control( new Corporate_Education_Pro_Dropdown_Single_Category_Control( $wp_customize, 'corporate_education_pro_theme_options[gallery_content_category]', array(
	'label'           => esc_html__( 'Select Category', 'corporate-education-pro' ),
	'description'     => esc_html__( 'Six Latest posts from selected category will be shown. Make sure post has featured image.', 'corporate-education-pro' ),
	'section'         => 'corporate_education_pro_gallery',
	'type'			  => 'dropdown-category',
	'active_callback' => 'corporate_education_pro_gallery_content_category',
) ) );

// gallery Section btn label gallery setting and control.
$wp_customize->add_setting( 'corporate_education_pro_theme_options[gallery_btn_label]', array(
	'default' 			=> $options['gallery_btn_label'],
	'sanitize_callback' => 'sanitize_text_field',
) );

$wp_customize->add_control( 'corporate_education_pro_theme_options[gallery_btn_label]', array(
	'active_callback'	=> 'corporate_education_pro_is_gallery_enable',
	'label'             => esc_html__( 'Input Button Label', 'corporate-education-pro' ),
	'section'           => 'corporate_education_pro_gallery',
	'type'				=> 'text',
) );

// gallery Section btn link gallery setting and control.
$wp_customize->add_setting( 'corporate_education_pro_theme_options[gallery_btn_link]', array(
	'default' 			=> $options['gallery_btn_link'],
	'sanitize_callback' => 'esc_url_raw',
) );

$wp_customize->add_control( 'corporate_education_pro_theme_options[gallery_btn_link]', array(
	'active_callback'	=> 'corporate_education_pro_is_gallery_enable',
	'label'             => esc_html__( 'Input Button Link', 'corporate-education-pro' ),
	'section'           => 'corporate_education_pro_gallery',
	'type'				=> 'url',
) );

