<?php
/**
 * Theme Palace widgets inclusion
 *
 * This is the template that includes all custom widgets of Theme Palace
 *
 * @package Theme Palace
 * @subpackage Corporate Education Pro
 * @since Corporate Education Pro 1.0
 */

/**
 * Register widget area.
 *
 * @link https://developer.wordpress.org/themes/functionality/sidebars/#registering-a-sidebar
 */
function corporate_education_pro_widgets_init() {

	register_sidebar( array(
		'name'          => esc_html__( 'Sidebar', 'corporate-education-pro' ),
		'id'            => 'sidebar-1',
		'description'   => esc_html__( 'Add widgets here.', 'corporate-education-pro' ),
		'before_widget' => '<section id="%1$s" class="widget %2$s">',
		'after_widget'  => '</section>',
		'before_title'  => '<h2 class="widget-title">',
		'after_title'   => '</h2>',
	) );

	// Header Widget Area
	register_sidebar( array(
		'name'          => esc_html__( 'Header Widget Area', 'corporate-education-pro' ),
		'id'            => 'header-widget',
		'description'   => esc_html__( 'Add widgets here.', 'corporate-education-pro' ),
		'before_widget' => '<div id="%1$s" class="widget %2$s">',
		'after_widget'  => '</div>',
		'before_title'  => '<h2 class="widget-title">',
		'after_title'   => '</h2>',
	) );

	// Optional Sidebar Widget Area
	register_sidebars( 3, array(
		'name'          => esc_html__( 'Optional Sidebar %d', 'corporate-education-pro' ),
		'id'            => 'corporate-education-pro-optional-sidebar',
		'description'   => esc_html__( 'Add widgets here.', 'corporate-education-pro' ),
		'before_widget' => '<section id="%1$s" class="widget %2$s">',
		'after_widget'  => '</section>',
		'before_title'  => '<h2 class="widget-title">',
		'after_title'   => '</h2>',
	) );

	// Footer Widget Area
	register_sidebars( 4, array(
		'name'          => esc_html__( 'Footer Widget Area %d', 'corporate-education-pro' ),
		'id'            => 'corporate-education-pro-footer-widget-area',
		'description'   => esc_html__( 'This Widget Area is for Footer Section.', 'corporate-education-pro' ),
		'before_widget' => '<div id="%1$s" class="widget %2$s">',
		'after_widget'  => '</div>',
		'before_title'  => '<h4 class="widget-title">',
		'after_title'   => '</h4>',
	) );

	// Contact Page Widget Area
	register_sidebar( array(
		'name'          => esc_html__( 'Contact Page Widget Area', 'corporate-education-pro' ),
		'id'            => 'contact-page-widget',
		'description'   => esc_html__( 'Add widgets here.', 'corporate-education-pro' ),
		'before_widget' => '<div id="%1$s" class="widget %2$s">',
		'after_widget'  => '</div>',
		'before_title'  => '<h2 class="widget-title">',
		'after_title'   => '</h2>',
	) );
}
add_action( 'widgets_init', 'corporate_education_pro_widgets_init' );

/*
 * Add social link widget
 */
require get_template_directory() . '/inc/widgets/social-link.php';
/*
 * Add Ad image widget
 */
require get_template_directory() . '/inc/widgets/ad-image.php';
/*
 * Add Contact info widget
 */
require get_template_directory() . '/inc/widgets/contact-info.php';
/*
 * Add instagram widget
 */
require get_template_directory() . '/inc/widgets/instagram.php';
/*
 * Add Latest Posts widget
 */
require get_template_directory() . '/inc/widgets/latest-posts.php';
/*
 * Add popular post meta
 */
require get_template_directory() . '/inc/widgets/popular-post/popular-post-meta.php';
/*
 * Add popular post widget
 */
require get_template_directory() . '/inc/widgets/popular-post/popular-post-widget.php';


function corporate_education_pro_register_widgets() {

	register_widget( 'Corporate_Education_Pro_Social_Link' );

	register_widget( 'Corporate_Education_Pro_Latest_Post' );

	register_widget( 'Corporate_Education_Pro_Instagram_Widget' );

	register_widget( 'Corporate_Education_Pro_Custom_Info_Widget' );

	register_widget( 'Corporate_Education_Pro_Image_Widget' );

	register_widget( 'Corporate_Education_Pro_Popular_Post' );
}
add_action( 'widgets_init', 'corporate_education_pro_register_widgets' );